CrispMain class

The main model for the CrispView

Constructors

CrispMain({required String websiteId, String locale = 'en', String? userToken, CrispUser? user})

Properties

commands ↔ Queue
Commands which are defined on register and executed on CrispView initState
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locale ↔ String
Locale to define which language the chat should appear
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user ↔ CrispUser?
The chat user model with possible additional data
getter/setter pair
userToken ↔ String?
The token of the user
getter/setter pair
websiteId → String
The id of your crisp chat
final

Methods

appendScript(String script) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({required CrispUser user}) → void
Register a new user to start the chat
setMessage(String text) → dynamic
setSegments(List<String> segments) → dynamic
setSessionData(Map<String, String> sessionData) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited