CrispUser class

Model for chat user data

Constructors

CrispUser({required String email, String? avatar, String? nickname, String? phone, String? verificationCode})
Creates a new instance of chat user to be user in CrispMain.register

Properties

avatar → String?
The avatar os this
final
email → String
The email of this
final
hashCode → int
The hash code for this object.
no setterinherited
nickname → String?
The nickname of this
final
phone → String?
The phone of this
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verificationCode → String?
The verification code of this
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited